@@ -2,12 +2,8 @@ from uuid import uuid4
 from base import Base
 import db_utils as db
 
-CASSANDRA_KEYSPACE = 'gradfly'
-CASSANDRA_IP = ['192.241.181.163', '107.170.88.98']
-
-
 class LookUp(Base):
-    __tablename__ = "lookuptable"
+    __tablename__ = "lookup"
 
     defaults = {
         "id": "",
@@ -21,11 +17,11 @@ class LookUp(Base):
 
     @staticmethod
     def _build(__tablename__):
-        build = "create table "+CASSANDRA_KEYSPACE+"."+__tablename__
+        build = "create table "+db.cass_keyspace+"."+__tablename__
         build += " ( id varchar PRIMARY KEY, model varchar, model_id uuid ) with caching = \'all\'"
         db.c.session.execute(build)
         db.c.session.execute("create index model on "
-                             +CASSANDRA_KEYSPACE+"."+__tablename__+" (model)")
+                             +db.cass_keyspace+"."+__tablename__+" (model)")
 
     @classmethod
     def build(cls):
